@@ -52,7 +52,7 @@ require DynaLoader;
 );
 
 require XSLoader;
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 XSLoader::load('Image::PNG', $VERSION);
 
@@ -209,7 +209,7 @@ a routine which reads data from Perl scalars. It then uses
 C<png_read_png> to read all the data.
 
 The C function which does this is called C<perl_png_scalar_read>, 
-L<in the file C<perl-libpng.c> in the top directory of the distribution|http://cpansearch.perl.org/src/BKB/Image-PNG-0.01/perl-libpng.c>.
+L<in the file C<perl-libpng.c> in the top directory of the distribution|http://cpansearch.perl.org/src/BKB/Image-PNG-0.02/perl-libpng.c>.
 
 See also L</Input/output manipulation functions>.
 
@@ -239,7 +239,7 @@ uses C<png_set_write_fn> to set the writing function of C<$png> to be
 its own function, which writes data to the Perl scalar.
 
 The C function which does this is called C<perl_png_scalar_write>, 
-L<in the file C<perl-libpng.c> in the top directory of the distribution|http://cpansearch.perl.org/src/BKB/Image-PNG-0.01/perl-libpng.c>.
+L<in the file C<perl-libpng.c> in the top directory of the distribution|http://cpansearch.perl.org/src/BKB/Image-PNG-0.02/perl-libpng.c>.
 
 See also L</Input/output manipulation functions>.
 
@@ -828,8 +828,7 @@ A PNG image may or may not contain a palette. To check whether the
 image contains a palette, use something of the following form:
 
      use Image::PNG::Const ':all';
-     my $color_type;
-     Image::PNG::Libpng::get_color_type ($png, \$color_type)
+     my $color_type = Image::PNG::Libpng::get_color_type ($png);
      if ($color_type == PNG_COLOR_TYPE_PALETTE) {
          # The PNG uses a palette.
      }
@@ -987,7 +986,7 @@ instances of unevaluated arguments, which have all been eliminated
 from this module.
 
 If you are interested in exactly which libpng arguments are omitted,
-you can find each instance L<in the file C<perl-libpng.c> in the top directory of the distribution|http://cpansearch.perl.org/src/BKB/Image-PNG-0.01/perl-libpng.c> in the macro
+you can find each instance L<in the file C<perl-libpng.c> in the top directory of the distribution|http://cpansearch.perl.org/src/BKB/Image-PNG-0.02/perl-libpng.c> in the macro
 C<UNUSED_ZERO_ARG>.
 
 =head2 Function return values are used to return values
